@@ -189,7 +189,7 @@ class transfer_learner():
             dic['num_classes'] = self.num_classes
             dic['labels'] = self.labels
             dic['class_names'] = self.class_names            
-            
+
             with open(PKL_PATH, 'wb') as f:
                 pickle.dump(dic, f)
 
@@ -370,22 +370,32 @@ class transfer_learner():
 
         convert_keras_to_tflite(best_model_path, fname, v1) 
 
-    def evaluate(self, N = 30):
+    def evaluate(self, X=None, y=None, N = 30):
+        
+        if X is None:
+            X = self.X_val
+        if y is None:
+            y = self.y_val
+
         custom_model = self.get_best_model()
 
-        N = min(N, len(self.X_val))
+        matched = []
+        N = min(N, len(X))
 
         fig = plt.figure(figsize=(20, 20*(N/10+1)))
         for i in range(N):    
-            p = custom_model.predict(np.expand_dims(self.X_val[i], axis=0))
+            p = custom_model.predict(np.expand_dims(X[i], axis=0))
             ax = fig.add_subplot(int(N/3)+1, 3, i+1)
-            x = restore_image(self.X_val[i])
+            x = restore_image(X[i])
             ax.imshow(x)
             # ax.imshow((X_val[i] - X_val[i].min())/(X_val[i].max()-X_val[i].min()))
-            title = 'Predict: {}\n {} \n Actual: {}'.format(self.class_names[int(p.argmax(-1))], np.round(p[0],2), 
-            self.class_names[int(self.y_val[i].argmax(-1))])
+            title = 'Predict: {}\n {} \n Actual: {}'.format(self.class_names[int(p.argmax(-1))], 
+            np.round(p[0],2), self.class_names[int(y[i].argmax(-1))])
             ax.set_title(title)
 
+            matched.append(p.argmax(-1) == y[i].argmax(-1))
+
+        return np.mean(matched) # return mean acc
 
     def predict_file(self, img_path, display = True, use_mask = False):
 
